==> tasks-v1.8.8.zip: tasks/messages/bg/base.php <==
<?php

return [
    '1 Day before' => '1 ден преди това',
    '1 Month before' => '1 месец преди това',
    '1 Week before' => '1 седмица преди това',
    '2 Days before' => '2 дена преди това',
    '2 Weeks before' => '2 седмици преди това',
    '3 Weeks before' => '3 седмици преди това',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Назначените потребители</strong> имат право да обработват тази задача.',
    '<strong>Confirm</strong> task deletion' => '<strong>Потвърди</strong> изтриването на задачата',
    '<strong>Create</strong> task list' => '<strong>Създай</strong> списък със задачи',
    '<strong>Edit</strong> task' => '<strong>Редактирай</strong> задача',
    '<strong>Edit</strong> task list' => '<strong>Редактирай</strong> списък със задачи',
    '<strong>Task</strong> Overview' => 'Общ преглед на <strong>задача</strong>',
    '<strong>Your</strong> tasks' => '<strong>Твоите</strong> задачи',
    'Accept Task' => 'Приеми задача',
    'Add Deadline to space calendar' => 'Добави краен срок към календара в раздела',
    'Add checkpoint...' => 'Добавяне на контролна точка ...',
    'Add reminder' => 'Добавяне на напомняне',
    'Add responsible users' => 'Добавяне на отговорни потребители',
    'Add schedule to the space calendar' => 'Добави график към календара в раздела',
    'Add task' => 'Добави задача',
    'Add to space calendar' => 'Добави календар в раздела',
    'All Day' => 'Цял ден',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Позволява на потребителя да създава нови задачи, потребителят ще може само да редактира и изтрива собствени задачи',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Позволява на потребителя да създава, изтрива и редактира задачи и списъци, както и да сортира задачи и списъци',
    'Allows the user to process unassigned tasks' => 'Позволява на потребителя да обработва незададени задачи',
    'Already requested' => 'Вече е заявена',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Всеки потребител с разрешение "Обработване на неназначени задачи" може да работи по тази задача',
    'Anyone can work on this task!' => 'Всеки може да работи по тази задача!',
    'Assign users' => 'Възложени потребители',
    'Assigned' => 'Назначени',
    'Assignment' => 'Възлагане',
    'Assignments:' => 'Задания:',
    'At least 1 Hour before' => 'Поне 1 час преди това',
    'At least 2 Hours before' => 'Поне 2 часа преди това',
    'Begin Task' => 'Започни задача',
    'Checklist Items' => 'Елементи от контролния списък',
    'Checklist:' => 'Контролен списък:',
    'Close' => 'Затвори',
    'Color' => 'Цвят',
    'Completed' => 'Завършени',
    'Continue Review' => 'Продължи прегледа',
    'Create tasks' => 'Създай задачи',
    'Created by me' => 'Създадени от мен',
    'Date' => 'Дата',
    'Deadline at' => 'Краен срок на',
    'Deadline: ' => 'Краен срок:',
    'Delete' => 'Изтрий',
    'Delete list' => 'Изтрий списък',
    'Description' => 'Описание',
    'Do not remind' => 'Не напомняй',
    'Do you really want to delete this task?' => 'Наистина ли искате да изтриете тази задача?',
    'Don\'t add to calendar' => 'Не добавяй в календара',
    'Drag entry' => 'Плъзнете записа',
    'Edit' => 'Редактирай',
    'Edit item (empty field will be removed)...' => 'Редактиране на елемент (празното поле ще бъде премахнато)...',
    'Edit list' => 'Редактирай списък',
    'End' => 'Край',
    'End Date' => 'Крайна дата',
    'End Time' => 'Крайно време',
    'End date' => 'Крайна дата',
    'End time must be after start time!' => 'Крайният час трябва да е след началния час!',
    'Extend deadline request' => 'Заявка за удължаване на краен срок',
    'Filter' => 'Филтър',
    'Filter tasks' => 'Филтрирайте задачи',
    'Finish Task' => 'Завърши задачата',
    'General' => 'Общ',
    'General Settings' => 'Основни Настройки',
    'Hide this list once all tasks are completed' => 'Скрий този списък, след като всички задачи са изпълнени',
    'I\'m assigned' => 'Аз съм назначен',
    'I\'m responsible' => 'Аз съм отговорен',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ако не е избран избран потребител, всеки член на раздела с разрешение за обработка на неназначени задачи може да обработи задачата.',
    'In Progress' => 'В процес на изпълнение',
    'In Review' => 'В процес на преглед',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'В случай, че опцията за преглед е активна, <strong>отговорен потребител</strong> ще трябва да прегледа и отхвърли или потвърди тази задача преди приключване.',
    'Invalid task list selection.' => 'Невалиден избор на списък със задачи.',
    'Let Task Review' => 'Преглед на задачата',
    'Manage tasks' => 'Управление на задачите',
    'No Scheduling set for this Task' => 'Няма зададен график за тази задача',
    'No pending tasks found' => 'Не са намерени чакащи задачи',
    'No results found for the given filter.' => 'Няма резултати за дадения филтър.',
    'Open Task' => 'Отвори задача',
    'Other Tasks' => 'Други задачи',
    'Overdue' => 'Просрочена',
    'Overview' => 'Общ преглед',
    'Parent Task' => 'Главна задача',
    'Pending' => 'Изчакваща',
    'Pending Review' => 'Изчаква преглед',
    'Process unassigned tasks' => 'Обработваване на неназначени задачи',
    'Ready For Review' => 'Готово за преглед',
    'Receive Notifications for Task Reminder.' => 'Получавайте известия за напомняне за задача.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Получавайте известия за задачи (актуализации на крайни срокове, промени в състоянието ...).',
    'Reject Task' => 'Отхвърляне на задача',
    'Remind Mode' => 'Режим на напомняне',
    'Reminder' => 'Напомняне',
    'Reminder sent' => 'Напомнянето е изпратено',
    'Reminders' => 'Напомняния',
    'Request extension' => 'Заявка за удължаване',
    'Request sent' => 'Заявката е изпратена',
    'Reset Task' => 'Нулиране на задачата',
    'Responsible' => 'Отговорен',
    'Review by responsible user required' => 'Изисква се преглед от отговорен потребител',
    'Scheduling' => 'Планиране',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Показване на {countTasks,plural,=1{# завършена задача} other{# завършени задачи}}',
    'Sort Order' => 'Сортирай ред',
    'Sort order' => 'Подреждане',
    'Spaces' => 'Раздели',
    'Start' => 'Старт',
    'Start Date' => 'Начална дата',
    'Start Time' => 'Начално време',
    'Start date' => 'Начална дата',
    'Starting at' => 'Започва в',
    'Status' => 'Статус',
    'Task' => 'Задача',
    'Task Users have been notified' => 'Потребителите, обвързани със задачата, са уведомени',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Задача {task} в раздел {spaceName} завършва в {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Задача {task} в раздел {spaceName} започва в {dateTime}.',
    'Tasks' => 'Задачи',
    'Tasks: Reminder' => 'Задачи: Напомняне',
    'This task can only be processed by assigned and responsible users.' => 'Тази задача може да бъде обработена само от назначени и отговорни потребители.',
    'This task requires to be reviewed by a responsible' => 'Тази задача изисква да бъде прегледана от отговорник',
    'Time Zone' => 'Часова зона',
    'Title' => 'Заглавие',
    'Title and Color' => 'Заглавие и цвят',
    'Today' => 'Днес',
    'Unsorted' => 'Несортиран',
    'View Online' => 'Виж онлайн',
    'You are assigned!' => 'Вие сте назначени!',
    'You are responsible!' => 'Вие сте отговорни!',
    'You have insufficient permissions to perform that operation!' => 'Нямате достатъчно разрешения за извършване на тази операция!',
    'Your Reminder for task {task}' => 'Вашето напомняне за задача {task}',
    'ending Review' => 'завърши преглед',
    'view all' => 'виж всички',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# ден остава} other{# дни остават}}',
    '{displayName} is assigned to this task' => 'Тази задача е възложена на {displayName}',
    '{displayName} is responsible for this task' => 'Отговорника по задачата е {displayName}',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} ви назначи като отговорно лице в задача {task} от раздел {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ви възложи на задача {task} в раздел {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} изпълни задача {task} в раздел {spaceName}.',
    '{userName} completed task {task}.' => '{userName} изпълни задача {task}.',
    '{userName} finished task {task}.' => '{userName} завърши задача {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} е променил крайния срок за задача {task} в раздела {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} отвори отново задача {task} в раздела {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} отхвърли задача {task} в раздела {spaceName} като незавършена.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} маркира задача {task} в раздел {spaceName} като завършена.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} иска удължаване на краен срок за задача {task} в раздел {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} иска да прегледате задача {task} в раздела {spaceName}.',
    '{userName} reset task {task}.' => '{userName} нулира задача {task}.',
    '{userName} reviewed task {task}.' => '{userName} прегледа задача {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} започна работа по Задача {task} в раздела {spaceName}.',
    '{userName} works on task {task}.' => '{userName} работи върху задача {task}.',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/bg/base.php <==
<?php

return [
    '1 Day before' => '1 ден преди това',
    '1 Month before' => '1 месец преди това',
    '1 Week before' => '1 седмица преди това',
    '2 Days before' => '2 дена преди това',
    '2 Weeks before' => '2 седмици преди това',
    '3 Weeks before' => '3 седмици преди това',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Назначените потребители</strong> имат право да обработват тази задача.',
    '<strong>Confirm</strong> task deletion' => '<strong>Потвърди</strong> изтриването на задачата',
    '<strong>Create</strong> task list' => '<strong>Създай</strong> списък със задачи',
    '<strong>Edit</strong> task' => '<strong>Редактирай</strong> задача',
    '<strong>Edit</strong> task list' => '<strong>Редактирай</strong> списък със задачи',
    '<strong>Task</strong> Overview' => 'Общ преглед на <strong>задача</strong>',
    '<strong>Your</strong> tasks' => '<strong>Твоите</strong> задачи',
    'Accept Task' => 'Приеми задача',
    'Add Deadline to space calendar' => 'Добави краен срок към календара в раздела',
    'Add checkpoint...' => 'Добавяне на контролна точка ...',
    'Add reminder' => 'Добавяне на напомняне',
    'Add responsible users' => 'Добавяне на отговорни потребители',
    'Add schedule to the space calendar' => 'Добави график към календара в раздела',
    'Add task' => 'Добави задача',
    'Add to space calendar' => 'Добави календар в раздела',
    'All Day' => 'Цял ден',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Позволява на потребителя да създава нови задачи, потребителят ще може само да редактира и изтрива собствени задачи',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Позволява на потребителя да създава, изтрива и редактира задачи и списъци, както и да сортира задачи и списъци',
    'Allows the user to process unassigned tasks' => 'Позволява на потребителя да обработва незададени задачи',
    'Already requested' => 'Вече е заявена',
    'Assign users' => 'Възложени потребители',
    'Assignment' => 'Възлагане',
    'At least 1 Hour before' => 'Поне 1 час преди това',
    'At least 2 Hours before' => 'Поне 2 часа преди това',
    'Begin Task' => 'Започни задача',
    'Checklist Items' => 'Елементи от контролния списък',
    'Checklist:' => 'Контролен списък:',
    'Close' => 'Затвори',
    'Color' => 'Цвят',
    'Completed' => 'Завършени',
    'Continue Review' => 'Продължи прегледа',
    'Create tasks' => 'Създай задачи',
    'Created by me' => 'Създадени от мен',
    'Date' => 'Дата',
    'Deadline: ' => 'Краен срок:',
    'Delete' => 'Изтрий',
    'Delete list' => 'Изтрий списък',
    'Description' => 'Описание',
    'Do not remind' => 'Не напомняй',
    'Do you really want to delete this task?' => 'Наистина ли искате да изтриете тази задача?',
    'Don\'t add to calendar' => 'Не добавяй в календара',
    'Edit' => 'Редактирай',
    'Edit item (empty field will be removed)...' => 'Редактиране на елемент (празното поле ще бъде премахнато)...',
    'Edit list' => 'Редактирай списък',
    'End' => 'Край',
    'End Date' => 'Крайна дата',
    'End Time' => 'Крайно време',
    'End date' => 'Крайна дата',
    'End time must be after start time!' => 'Крайният час трябва да е след началния час!',
    'Extend deadline request' => 'Заявка за удължаване на краен срок',
    'Filter' => 'Филтър',
    'Filter tasks' => 'Филтрирайте задачи',
    'Finish Task' => 'Завърши задачата',
    'General' => 'Общ',
    'General Settings' => 'Основни Настройки',
    'Hide this list once all tasks are completed' => 'Скрий този списък, след като всички задачи са изпълнени',
    'I\'m assigned' => 'Аз съм назначен',
    'I\'m responsible' => 'Аз съм отговорен',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ако не е избран избран потребител, всеки член на раздела с разрешение за обработка на неназначени задачи може да обработи задачата.',
    'In Progress' => 'В процес на изпълнение',
    'In Review' => 'В процес на преглед',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'В случай, че опцията за преглед е активна, <strong>отговорен потребител</strong> ще трябва да прегледа и отхвърли или потвърди тази задача преди приключване.',
    'Invalid task list selection.' => 'Невалиден избор на списък със задачи.',
    'Let Task Review' => 'Преглед на задачата',
    'Manage tasks' => 'Управление на задачите',
    'No Scheduling set for this Task' => 'Няма зададен график за тази задача',
    'No pending tasks found' => 'Не са намерени чакащи задачи',
    'No results found for the given filter.' => 'Няма резултати за дадения филтър.',
    'Open Task' => 'Отвори задача',
    'Other Tasks' => 'Други задачи',
    'Overdue' => 'Просрочена',
    'Overview' => 'Общ преглед',
    'Parent Task' => 'Главна задача',
    'Pending' => 'Изчакваща',
    'Pending Review' => 'Изчаква преглед',
    'Process unassigned tasks' => 'Обработваване на неназначени задачи',
    'Ready For Review' => 'Готово за преглед',
    'Receive Notifications for Task Reminder.' => 'Получавайте известия за напомняне за задача.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Получавайте известия за задачи (актуализации на крайни срокове, промени в състоянието ...).',
    'Reject Task' => 'Отхвърляне на задача',
    'Remind Mode' => 'Режим на напомняне',
    'Reminder' => 'Напомняне',
    'Reminder sent' => 'Напомнянето е изпратено',
    'Reminders' => 'Напомняния',
    'Request extension' => 'Заявка за удължаване',
    'Request sent' => 'Заявката е изпратена',
    'Reset Task' => 'Нулиране на задачата',
    'Responsible' => 'Отговорен',
    'Review by responsible user required' => 'Изисква се преглед от отговорен потребител',
    'Scheduling' => 'Планиране',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Показване на {countTasks,plural,=1{# завършена задача} other{# завършени задачи}}',
    'Sort Order' => 'Сортирай ред',
    'Sort order' => 'Подреждане',
    'Spaces' => 'Раздели',
    'Start' => 'Старт',
    'Start Date' => 'Начална дата',
    'Start Time' => 'Начално време',
    'Start date' => 'Начална дата',
    'Starting at' => 'Започва в',
    'Status' => 'Статус',
    'Task' => 'Задача',
    'Task Users have been notified' => 'Потребителите, обвързани със задачата, са уведомени',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Задача {task} в раздел {spaceName} завършва в {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Задача {task} в раздел {spaceName} започва в {dateTime}.',
    'Tasks' => 'Задачи',
    'Tasks: Reminder' => 'Задачи: Напомняне',
    'This task requires to be reviewed by a responsible' => 'Тази задача изисква да бъде прегледана от отговорник',
    'Time Zone' => 'Часова зона',
    'Title' => 'Заглавие',
    'Title and Color' => 'Заглавие и цвят',
    'Today' => 'Днес',
    'Unsorted' => 'Несортиран',
    'View Online' => 'Виж онлайн',
    'You have insufficient permissions to perform that operation!' => 'Нямате достатъчно разрешения за извършване на тази операция!',
    'Your Reminder for task {task}' => 'Вашето напомняне за задача {task}',
    'view all' => 'виж всички',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# ден остава} other{# дни остават}}',
    '{displayName} is assigned to this task' => 'Тази задача е възложена на {displayName}',
    '{displayName} is responsible for this task' => 'Отговорника по задачата е {displayName}',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} ви назначи като отговорно лице в задача {task} от раздел {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} ви възложи на задача {task} в раздел {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} изпълни задача {task} в раздел {spaceName}.',
    '{userName} completed task {task}.' => '{userName} изпълни задача {task}.',
    '{userName} finished task {task}.' => '{userName} завърши задача {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} е променил крайния срок за задача {task} в раздела {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} отвори отново задача {task} в раздела {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} отхвърли задача {task} в раздела {spaceName} като незавършена.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} маркира задача {task} в раздел {spaceName} като завършена.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} иска удължаване на краен срок за задача {task} в раздел {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} иска да прегледате задача {task} в раздела {spaceName}.',
    '{userName} reset task {task}.' => '{userName} нулира задача {task}.',
    '{userName} reviewed task {task}.' => '{userName} прегледа задача {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} започна работа по Задача {task} в раздела {spaceName}.',
    '{userName} works on task {task}.' => '{userName} работи върху задача {task}.',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignments' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'Request Review' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Task List' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
    '{displayName} is task creator' => '',
];
